import "./tasks/fastqc.wdl" as fastqc
import "./tasks/fastqscreen.wdl" as fastqscreen
import "./tasks/bamqc.wdl" as bamqc
import "./tasks/benchmark.wdl" as benchmark

workflow {{ project_name }} {

	File inputSamplesFile
	Array[Array[File]] inputSamples = read_tsv(inputSamplesFile)
	File screen_ref_dir
	File fastq_screen_conf
	File benchmarking_dir
	File ref_dir
	String fasta

	scatter (sample in inputSamples){
		call fastqc.fastqc as fastqc {
			input:
			read1=sample[0],
			read2=sample[1]
		}

		call fastqscreen.fastq_screen as fastqscreen {
			input:
			read1=sample[0],
			read2=sample[1],
			screen_ref_dir=screen_ref_dir,
			fastq_screen_conf=fastq_screen_conf
		}

		call bamqc.bamqc as bamqc {
			input:
			bam=sample[2],
			bai=sample[3]
		}

		call benchmark.benchmark as benchmark {
			input:
			vcf=sample[4],
			benchmarking_dir=benchmarking_dir,
			ref_dir=ref_dir,
			sample_mark=sample[5],
			fasta=fasta
		}
	}

}

